@@ -79,7 +79,7 @@ setClass('RasterFile',
 		),
 	prototype (	
 	    name = '',
-		datanotation='FLT4S',
+		datanotation='FLT8S',
 		byteorder = .Platform$endian,
 		nodatavalue = -3.4E38,
 		nbands = as.integer(1),
@@ -89,7 +89,7 @@ setClass('RasterFile',
 		driver = '' # raster or gdal
 	),
 	validity = function(object) {
-		c1 <- datanotation %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT8S', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')
+		c1 <- datanotation %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')
 		return(c1)
 	}
 )
