@@ -107,11 +107,11 @@
 	if (missing(datatype)) { 
 		datatype <- getOption('rasterDatatype')
 		if (is.null(datatype)) {
-			return('FLT4S') 
+			return('FLT8S') 
 		} 
 	} 
-	if (! datatype %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT8S', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')) {
-		warning(datatype, ' is an invalid datatype, changed to FLT4S')
+	if (! datatype %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT1U', 'INT2U', 'INT4U', 'FLT4S', 'FLT8S')) {
+		warning(datatype, ' is an invalid datatype, changed to FLT8S')
 	}
 	return(datatype)
 }
