@@ -17,8 +17,11 @@ setOptions <- function(format, overwrite, datatype, tmpdir, progress, timer, chu
 	}
 	
 	setDataType <- function(datatype) {
-		if (datatype %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT8S', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')) {	options(rasterDatatype = datatype)
-		} else { warning(paste('Cannot set datatype to unknown type:',datatype))	}
+		if (datatype %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT4U', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')) {	
+			options(rasterDatatype = datatype)
+		} else { 
+			warning(paste('Cannot set datatype to unknown type:',datatype))	
+		}
 	}
 	
 	setTmpdir <- function(tmpdir) {
